Official interfaces for ST components.

Dependents:   X_NUCLEO_IKS01A1 mDot_X_NUCLEO_IKS01A1 53L0A1 X_NUCLEO_IKS01A1 ... more

Fork of ST_INTERFACES by Davide Aliprandi

This library contains all abstract classes which together constitute the common API to which all existing and future ST components will adhere to.

Revision:
3:b1bb477e115e
Parent:
1:a7810e7acf8d
--- a/Sensors/MagneticSensor.h	Tue Nov 29 17:43:48 2016 +0000
+++ b/Sensors/MagneticSensor.h	Fri Mar 10 10:50:53 2017 +0100
@@ -36,42 +36,54 @@
  ******************************************************************************
  */
 
+
 /* Define to prevent from recursive inclusion --------------------------------*/
+
 #ifndef __MAGNETIC_SENSOR_CLASS_H
 #define __MAGNETIC_SENSOR_CLASS_H
 
+
 /* Includes ------------------------------------------------------------------*/
-#include <ComponentObject.h>
+
+#include <Component.h>
+
 
 /* Classes  ------------------------------------------------------------------*/
-/** An abstract class for a magnetometer
+
+/**
+ * An abstract class for a magnetometer
  */
-class MagneticSensor : public ComponentObject
-{
- public:
+class MagneticSensor : public Component {
+public:
+
 	/**
 	 * @brief       Get current magnetometer magnetic X/Y/Z-axes values 
 	 *              in standard data units [mgauss]
 	 * @param[out]  pData Pointer to where to store magnetic values to.
 	 *              pData must point to an array of (at least) three elements, where:
 	 *              pData[0] corresponds to X-axis,
 	 *              pData[1] corresponds to Y-axis, and
 	 *              pData[2] corresponds to Z-axis.
 	 * @return      0 in case of success, an error code otherwise
 	 */
-	virtual int Get_M_Axes(int32_t *pData) = 0;
+	virtual int get_m_axes(int32_t *p_data) = 0;
 
 	/**
 	 * @brief       Get current magnetometer raw data X/Y/Z-axes values 
 	 *              in device sepcific LSB units
 	 * @param[out]  pData Pointer to where to store magnetometer raw data to.
 	 *              pData must point to an array of (at least) three elements, where:
 	 *              pData[0] corresponds to X-axis,
 	 *              pData[1] corresponds to Y-axis, and
 	 *              pData[2] corresponds to Z-axis.
 	 * @return      0 in case of success, an error code otherwise
 	 */
-	virtual int Get_M_AxesRaw(int16_t *pData) = 0;
+	virtual int get_m_axes_raw(int16_t *p_data) = 0;
+
+    /**
+     * @brief Destructor.
+     */
+	virtual ~MagneticSensor() {};
 };
 
 #endif /* __MAGNETIC_SENSOR_CLASS_H */
@@ -36,42 +36,54 @@
 	 * @brief       Get current magnetometer magnetic X/Y/Z-axes values 
 	 *              in standard data units [mgauss]
-	 * @param[out]  pData Pointer to where to store magnetic values to.
-	 *              pData must point to an array of (at least) three elements, where:
-	 *              pData[0] corresponds to X-axis,
-	 *              pData[1] corresponds to Y-axis, and
-	 *              pData[2] corresponds to Z-axis.
+	 * @param[out]  p_data Pointer to where to store magnetic values to.
+	 *              p_data must point to an array of (at least) three elements, where:
+	 *              p_data[0] corresponds to X-axis,
+	 *              p_data[1] corresponds to Y-axis, and
+	 *              p_data[2] corresponds to Z-axis.
 	 * @return      0 in case of success, an error code otherwise
 	 */
@@ -36,42 +36,54 @@
 	 * @brief       Get current magnetometer raw data X/Y/Z-axes values 
 	 *              in device sepcific LSB units
-	 * @param[out]  pData Pointer to where to store magnetometer raw data to.
-	 *              pData must point to an array of (at least) three elements, where:
-	 *              pData[0] corresponds to X-axis,
-	 *              pData[1] corresponds to Y-axis, and
-	 *              pData[2] corresponds to Z-axis.
+	 * @param[out]  p_data Pointer to where to store magnetometer raw data to.
+	 *              p_data must point to an array of (at least) three elements, where:
+	 *              p_data[0] corresponds to X-axis,
+	 *              p_data[1] corresponds to Y-axis, and
+	 *              p_data[2] corresponds to Z-axis.
 	 * @return      0 in case of success, an error code otherwise
 	 */